@@ -30,7 +30,9 @@ pub trait ToTypeDef {
 static KNOWN_TYPES: Lazy<HashMap<&'static str, &'static str>> = Lazy::new(|| {
   let mut map = HashMap::default();
   map.extend([
+    ("JsUndefined", "undefined"),
     ("()", "undefined"),
+    ("JsNumber", "number"),
     ("i8", "number"),
     ("i16", "number"),
     ("i32", "number"),
@@ -40,17 +42,22 @@ static KNOWN_TYPES: Lazy<HashMap<&'static str, &'static str>> = Lazy::new(|| {
     ("u16", "number"),
     ("u32", "number"),
     ("u64", "BigInt"),
+    ("i64n", "BigInt"),
     ("u128", "BigInt"),
     ("i128", "BigInt"),
     ("usize", "BigInt"),
     ("isize", "BigInt"),
+    ("JsBigInt", "BigInt"),
     ("BigInt", "BigInt"),
+    ("JsBoolean", "boolean"),
     ("bool", "boolean"),
+    ("JsString", "string"),
     ("String", "string"),
     ("str", "string"),
     ("Latin1String", "string"),
     ("Utf16String", "string"),
     ("char", "string"),
+    ("JsObject", "object"),
     ("Object", "object"),
     ("Value", "any"),
     ("Map", "Record<string, any>"),
@@ -69,10 +76,12 @@ static KNOWN_TYPES: Lazy<HashMap<&'static str, &'static str>> = Lazy::new(|| {
     ("Either5", "{} | {} | {} | {} | {}"),
     ("unknown", "unknown"),
     ("null", "null"),
-    ("symbol", "symbol"),
+    ("Symbol", "symbol"),
+    ("JsSymbol", "symbol"),
     ("external", "object"),
     ("AbortSignal", "AbortSignal"),
-    ("Function", "(...args: any[]) => any"),
+    ("JsFunction", "(...args: any[]) => any"),
+    ("JsGlobal", "typeof global"),
   ]);
 
   map
@@ -153,6 +162,8 @@ pub fn ty_to_ts_type(ty: &Type, is_return_ty: bool) -> String {
           .with(|c| c.borrow_mut().get(rust_ty.as_str()).cloned())
         {
           ts_ty = Some(t);
+        } else if rust_ty == "Promise" {
+          ts_ty = Some(format!("Promise<{}>", args.first().unwrap()));
         } else {
           // there should be runtime registered type in else
           ts_ty = Some(rust_ty);
